<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>File</name>
    <message>
        <location filename="../File.js" line="+65"/>
        <source>File Tools</source>
        <translation>Herramientas archivo</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show file tools</source>
        <translation>Herramientas archivo</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>&amp;Fichero</translation>
    </message>
    <message>
        <location line="+91"/>
        <location line="+69"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="-32"/>
        <source>Overwrite File?</source>
        <translatorcomment>--exact match--
--file: qgis_es.ts--
¿Sobrescribir archivo?
El archivo ya existe:
&apos;%1&apos;
Sobrescribir?</translatorcomment>
        <translation>¿Sobrescribir archivo?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--exact match--
--file: Save_es.ts--
El archivo &apos;%1&apos; ya existe. ¿Desea sobreescribirlo?</translatorcomment>
        <translation>El archivo &apos;%1&apos; ya existe. ¿Desea sobreescribirlo?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All Files</source>
        <translation>Todos los archivos</translation>
    </message>
</context>
</TS>
